Welcome to Orange3-Prototypes documentation!
============================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/scoring-sheet
   widgets/scoring-sheet-viewer


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
